@@ -165,9 +165,17 @@ predict.emc <- function(object,hyper=FALSE,n_post=50,n_cores=1,
         }
       }
     }
-    simDat <- mclapply(1:n_post,function(i){
+    simDat <- suppressWarnings(mclapply(1:n_post,function(i){
       do.call(make_data, c(list(pars[[i]],design=design[[j]],data=data[[j]]), fix_dots(dots, make_data)))
-    },mc.cores=n_cores)
+    },mc.cores=n_cores))
+    in_bounds <- !sapply(simDat, is.logical)
+    if(all(!in_bounds)) stop("All samples fall outside of model bounds")
+    if(any(!in_bounds)){
+      good_post <- sample(1:n_post, sum(!in_bounds))
+      simDat[!in_bounds] <- suppressWarnings(mclapply(good_post,function(i){
+        do.call(make_data, c(list(pars[[i]],design=design[[j]],data=data[[j]]), fix_dots(dots, make_data)))
+      },mc.cores=n_cores))
+    }
     out <- cbind(postn=rep(1:n_post,times=unlist(lapply(simDat,function(x)dim(x)[1]))),do.call(rbind,simDat))
     if (n_post==1) pars <- pars[[1]]
     attr(out,"pars") <- pars
